
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.SimpleTimeZone;
import java.util.TimeZone;

/**
 * Zeitmessungen & Kalenderfunktionen <BR>
 * @version v.0.2 <BR>
 * @author TET <BR>
 */
public class MISC_Times 
{
	private Calendar cal1 = Calendar.getInstance();
	private Calendar machineread = Calendar.getInstance();
	private Calendar machinestart = Calendar.getInstance();

	/**
	 * setzt die startzeit <BR>
	 */
	public void startZeit()
	{
		SimpleDateFormat fmt = new SimpleDateFormat();
		fmt.applyPattern( "HH:mm:ss:SSS" );				//zeitformatiernung
		fmt.format(cal1.getTime());
	}

	/**
	 * ermittelt aus der startzeit und der aktuellen die differenz und gibt diese zurck <BR>
	 * @return endzeit in millisekunden <BR>
	 */
	public long endZeit()
	{
		long endzeit = (Calendar.getInstance().getTimeInMillis() - cal1.getTimeInMillis());
		return endzeit;
	}

	public static String aktuelleZeitinMillis() {
		String zeit = "";
		Calendar zeitheute = Calendar.getInstance();		
		zeit += String.valueOf(zeitheute.getTimeInMillis());
		return zeit;
	}
	/**
	 * gibt das aktuelle datum mit zeit zurck, als beispiel
	 * der 21. dezember 2007 um 10 Uhr 19 im format:
	 * yyyyMMddHHmm => 20071221019 
	 * @return aktuelleZeit
	 */
	public static String aktuelleZeit() {
		// create a time zone (berlin +1)
		String[] ids = TimeZone.getAvailableIDs(+1 * 60 * 60 * 1000);
		SimpleTimeZone pdt = new SimpleTimeZone(+1 * 60 * 60 * 1000, ids[23]);
		// set up rules for daylight savings time
		pdt.setStartRule(Calendar.APRIL, 1, Calendar.SUNDAY, 2 * 60 * 60 * 1000);
		pdt.setEndRule(Calendar.OCTOBER, -1, Calendar.SUNDAY, 2 * 60 * 60 * 1000);
		Date trialTime = new Date();
		Calendar calendar = new GregorianCalendar(pdt);
		calendar.setTime(trialTime);
		StringBuilder zeit = new StringBuilder();
		zeit.append(calendar.get(Calendar.YEAR));
		int monat = Integer.valueOf(calendar.get(Calendar.MONTH));
		zeit.append( monat+1 );
		zeit.append(calendar.get(Calendar.DAY_OF_MONTH));
		zeit.append(calendar.get(Calendar.HOUR));
		zeit.append(calendar.get(Calendar.MINUTE));
		return zeit.toString();
	}
	/**
	 * gibt das aktuelle datum aus, im format
	 * yyyy.MM.dd@hh:mm - als beispiel : 2007.12.30@12:46
	 * @return yyyy.MM.dd@hh:mm
	 */
	public static String gibAktuellesDatum(){
		GregorianCalendar cal = new GregorianCalendar( Locale.GERMANY );
		String max = "xx";
		String[] sammelKalender = dereineKalender(cal, max);
		return (sammelKalender[0]+"."+sammelKalender[1]+"."+sammelKalender[2]+"@"+
				sammelKalender[3]+":"+sammelKalender[4]);
	}	
	/**
	 * gibt das aktuelle datum aus, im format (fixed offset)
	 * yyyy-MM-ddThh:mm:sec+1:00 als Beispiel 2007-06-1T12:30:00+01:00
	 * @return yyyy-MM-ddThh:mm:sec+1:00
	 */
	public static String gibAktuellesHTMLDatum(){
		GregorianCalendar cal = new GregorianCalendar( Locale.GERMANY );
		String max = "xx";
		String[] sammelKalender = dereineKalender(cal, max);
		return (sammelKalender[0]+"-"+sammelKalender[1]+"-"+sammelKalender[2]+"T"+
				sammelKalender[3]+":"+sammelKalender[4]+":"+sammelKalender[5]+"+1:00");
	}
	/**
	 * gibt das aktuelle datum aus, im format (fixed offset)
	 * yyyy-MM-dd als Beispiel 2007-06-01
	 * @return yyyy-MM-dd
	 */
	public static String gibAktuellesXMLDatum(){
		GregorianCalendar cal = new GregorianCalendar( Locale.GERMANY );
		String max = "xx";
		String[] sammelKalender = dereineKalender(cal, max);
		return (sammelKalender[0]+"-"+sammelKalender[1]+"-"+sammelKalender[2]);
	}	
	/**
	 * wandelt aus millisec das tagesdatum
	 * yyyyMMdd.hhmm - als beispiel : 20071230.1246
	 * @param millisec
	 * @return yyMMdd.hhmm
	 */
	public static String machDatumausMilliSec(long millisec){
		GregorianCalendar cal = new GregorianCalendar();
		cal.setTimeInMillis(millisec);
		String max = "xx";
		String[] sammelKalender = dereineKalender(cal, max);
		return (sammelKalender[0]+"."+sammelKalender[1]+"."+sammelKalender[2]+"@"+
				sammelKalender[3]+":"+sammelKalender[4]);
	}
	/**
	 * gibt mal den kalender vorgesiebt
	 * @param cal - kalender der gemnzt werden soll (gregorian)
	 * @param max - stellen zum auffllen "xx"
	 * @return kalnderdaten im array
	 */
	private static String[] dereineKalender(GregorianCalendar cal, String max){
		String[] sammelKalender = new String[6];
		sammelKalender[0] = String.valueOf(cal.get(Calendar.YEAR));
		sammelKalender[1] = String.valueOf(cal.get(Calendar.MONTH)+1);
		if (sammelKalender[1].length()==1) sammelKalender[1]=MISC_Tool.fillLeft(sammelKalender[1],max,'0');
		sammelKalender[2] = String.valueOf(cal.get(Calendar.DAY_OF_MONTH));
		if (sammelKalender[2].length()==1) sammelKalender[2]=MISC_Tool.fillLeft(sammelKalender[2],max,'0');
		sammelKalender[3] = String.valueOf(cal.get(Calendar.HOUR_OF_DAY));
		if (sammelKalender[3].length()==1) sammelKalender[3]=MISC_Tool.fillLeft(sammelKalender[3],max,'0');
		sammelKalender[4] = String.valueOf(cal.get(Calendar.MINUTE));
		if (sammelKalender[4].length()==1) sammelKalender[4]=MISC_Tool.fillLeft(sammelKalender[4],max,'0');
		sammelKalender[5] = String.valueOf(cal.get(Calendar.SECOND));
		if (sammelKalender[5].length()==1) sammelKalender[5]=MISC_Tool.fillLeft(sammelKalender[5],max,'0');
		return sammelKalender;
	}

	public Calendar setReadDate(int day, int month, int year, int hour, int minute)
	{
		//set(int year, int month, int date, int hour, int minute)
		machineread.set(year,month,day,hour,minute);
		return machineread;
	}

	public Calendar setStartDate(int day, int month, int year, int hour, int minute)
	{
		//set(int year, int month, int date, int hour, int minute)
		machinestart.set(year,month,day,hour,minute);
		return machinestart;
	}
}
